import type { AxiosError } from 'axios';
import type { DataTableFilterMeta } from 'primevue/datatable';
import { RouteLocationRaw } from 'vue-router';
export declare const ACCEPT_TYPES: {
    CSV: string;
    JSON: string;
};
export declare const COUNT_TYPE: {
    Exact: string;
    Planned: string;
};
export declare const RETURN_TYPE: {
    Presentation: string;
    Representation: string;
};
export declare const EnviromentTypes: string[];
export type EnviromentType = (typeof EnviromentTypes)[number];
export type EnvironmentVariables = {
    title: string;
    api_url_private: string;
    api_url_public: string;
    log_api_calls: boolean;
};
export type Phone = {
    prefix: number | undefined | null;
    number: number | undefined | null;
};
export type Country = {
    country_code: string;
    country_name: string;
    country_prefix: number;
    is_allowed: boolean;
};
export type AuthUser = {
    username: string;
};
export type AuthState = {
    user?: AuthUser;
    accessToken?: string;
    returnRoute?: RouteLocationRaw;
};
export type LoadingStatus = {
    isLoading: boolean;
    error: AxiosError | string | undefined;
};
export type MenuItem = {
    label: string;
    icon?: string;
    routeName?: string;
    href?: string;
    target?: string;
    class?: string;
    category?: string;
    children?: Array<MenuItem>;
};
export type KeyValuePair = {
    key: string;
    value: any;
};
export type RequestHeaderOptions = {
    accept: string;
    countType?: string | null;
    returnType?: string | null;
    hash?: string;
};
export type PagedEnumerable<T> = {
    data?: T[];
    exportData?: string;
    totalRows: number;
    error?: any;
};
export declare const SortDirections: string[];
export type SortDirection = (typeof SortDirections)[number];
export type PaginationOptions = {
    Offset?: number;
    Limit?: number;
    Order: string;
    Sort: SortDirection;
};
export type DataTableLazyParams = {
    first: number;
    rows: number;
    sortField: string | ((item: any) => string) | undefined;
    sortOrder: 1 | 0 | -1 | undefined | null;
    filters: DataTableFilterMeta;
};
export type RouteOptions = {
    pageTitle?: string;
    cssClass?: string;
};
export type PostgRESTException = {
    hint: string;
    details: string;
    code: string;
    message: string;
};
export type FullTextSearchOptions<T> = {
    originalArray: Array<T>;
    searchKeys: Array<string>;
    searchQuery?: string;
    previous_searchQuery?: string;
    filteredArray?: Array<T>;
};
export type SelectOption = {
    value: string | null;
    text: string;
};
export type DateRange = {
    start: Date;
    end: Date;
    duration: number;
};
export declare enum ToastSeverities {
    SUCCESS = "success",
    INFO = "info",
    WARN = "warn",
    ERROR = "error"
}
export declare enum FilterMatchModes {
    STARTS_WITH = "startsWith",
    CONTAINS = "contains",
    NOT_CONTAINS = "notContains",
    ENDS_WITH = "endsWith",
    EQUALS = "equals",
    NOT_EQUALS = "notEquals",
    IN = "in",
    LESS_THAN = "lt",
    LESS_THAN_OR_EQUAL_TO = "lte",
    GREATER_THAN = "gt",
    GREATER_THAN_OR_EQUAL_TO = "gte",
    BETWEEN = "between",
    DATE_IS = "dateIs",
    DATE_IS_NOT = "dateIsNot",
    DATE_BEFORE = "dateBefore",
    DATE_AFTER = "dateAfter"
}
export declare enum FilterOperators {
    AND = "and",
    OR = "or"
}
